Crate rust_eigenda_v2_common

Crate rust_eigenda_v2_common 

Structs

Attestation
BatchHeaderV2
BatchHeaderV2Contract
Blob
Blob is data that is dispersed on EigenDA.
BlobCertificate
BlobCertificate contains a full description of a blob and how it is dispersed. Part of the certificate is provided by the blob submitter (i.e. the blob header), and part is provided by the disperser (i.e. the relays). Validator nodes eventually sign the blob certificate once they are in custody of the required chunks (note that the signature is indirect; validators sign the hash of a Batch, which contains the blob certificate).
BlobCertificateContract
BlobCommitmentContract
BlobCommitments
BlomCommitments contains the blob’s commitment, degree proof, and the actual degree.
BlobHeader
BlobHeaderV2Contract
BlobInclusionInfo
BlobInclusionInfo is the information needed to verify the inclusion of a blob in a batch.
BlobInclusionInfoContract
EigenDACert
Contains all data necessary to retrieve and validate a [Blob]
EigenDACertV3Contract
EncodedPayload
EncodedPayload represents a payload that has had an encoding applied to it.
G1PointContract
G2PointContract
NonSignerStakesAndSignature
NonSignerStakesAndSignatureContract
Payload
Payload represents arbitrary user data, without any processing.
PaymentHeader
PaymentHeader represents the header information for a blob
SignedBatch
SignedBatch is a batch of blobs with a signature.

Enums

BlobError
Errors specific to the Blob type
CheckDACertStatus
ConversionError
Errors specific to conversion
EigenDACertError
Errors specific to the EigenDA certificate
PayloadForm
The form of a payload dictates what conversion, if any, must be performed when creating a blob from the payload.

Functions

g1_commitment_from_bytes
g1_commitment_from_bytes converts a byte slice to a G1Affine point. The points received are in compressed form.
g1_commitment_to_bytes
Serialize a G1Affine point applying necessary flags. https://github.com/Consensys/gnark-crypto/blob/5fd6610ac2a1d1b10fae06c5e552550bf43f4d44/ecc/bn254/marshal.go#L790-L801
g2_commitment_from_bytes
g2_commitment_from_bytes converts a byte slice to a G2Affine point.
g2_commitment_to_bytes
Serialize a G2Affine point applying necessary flags.