Structs
- Attestation
- Batch
Header V2 - Batch
Header V2Contract - Blob
Blobis data that is dispersed on EigenDA.- Blob
Certificate - BlobCertificate contains a full description of a blob and how it is dispersed. Part of the certificate is provided by the blob submitter (i.e. the blob header), and part is provided by the disperser (i.e. the relays). Validator nodes eventually sign the blob certificate once they are in custody of the required chunks (note that the signature is indirect; validators sign the hash of a Batch, which contains the blob certificate).
- Blob
Certificate Contract - Blob
Commitment Contract - Blob
Commitments - BlomCommitments contains the blob’s commitment, degree proof, and the actual degree.
- Blob
Header - Blob
Header V2Contract - Blob
Inclusion Info - BlobInclusionInfo is the information needed to verify the inclusion of a blob in a batch.
- Blob
Inclusion Info Contract - EigenDA
Cert - Contains all data necessary to retrieve and validate a [
Blob] - EigenDA
Cert V3Contract - Encoded
Payload EncodedPayloadrepresents a payload that has had an encoding applied to it.- G1Point
Contract - G2Point
Contract - NonSigner
Stakes AndSignature - NonSigner
Stakes AndSignature Contract - Payload
- Payload represents arbitrary user data, without any processing.
- Payment
Header - PaymentHeader represents the header information for a blob
- Signed
Batch - SignedBatch is a batch of blobs with a signature.
Enums
- Blob
Error - Errors specific to the Blob type
- CheckDA
Cert Status - Conversion
Error - Errors specific to conversion
- EigenDA
Cert Error - Errors specific to the EigenDA certificate
- Payload
Form - The form of a payload dictates what conversion, if any, must be performed when creating a blob from the payload.
Functions
- g1_
commitment_ from_ bytes - g1_commitment_from_bytes converts a byte slice to a G1Affine point. The points received are in compressed form.
- g1_
commitment_ to_ bytes - Serialize a G1Affine point applying necessary flags. https://github.com/Consensys/gnark-crypto/blob/5fd6610ac2a1d1b10fae06c5e552550bf43f4d44/ecc/bn254/marshal.go#L790-L801
- g2_
commitment_ from_ bytes - g2_commitment_from_bytes converts a byte slice to a G2Affine point.
- g2_
commitment_ to_ bytes - Serialize a G2Affine point applying necessary flags.